@@ -518,8 +518,8 @@ class SocketUdpNb(object):
         #bind to Host Address Port
         try:
             self.ss.bind(self.ha)
-        except socket.error, e:
-            console.terse("socket.error = {0}\n".format(e))
+        except socket.error as ex:
+            console.terse("socket.error = {0}\n".format(ex))
             return False
 
         self.ha = self.ss.getsockname() #get resolved ha after bind
@@ -565,8 +565,8 @@ class SocketUdpNb(object):
                 self.rxLog.write("%s\n%s\n" % (str(sa), repr(data)))
 
             return (data,sa)
-        except socket.error, ex1: # 2.6 socket.error is subclass of IOError
-            if ex1.errno == errno.EAGAIN: #Resource temporarily unavailable on os x
+        except socket.error as ex: # 2.6 socket.error is subclass of IOError
+            if ex.errno == errno.EAGAIN: #Resource temporarily unavailable on os x
                 return ('',None) #receive has nothing empty string for data
             else:
                 raise #re raise exception ex1
@@ -580,8 +580,8 @@ class SocketUdpNb(object):
         """
         try:
             result = self.ss.sendto(data,da) #result is number of bytes sent
-        except socket.error, e:
-            print "socket.error = %s" % e
+        except socket.error as ex:
+            print "socket.error = %s" % ex
             result = 0
 
         console.profuse("Server at {0} sent {1} bytes\n".format(str(self.ha),result))
@@ -601,7 +601,7 @@ class SocketUxdNb(object):
        Needs socket module
     """
 
-    def __init__(self, ha=None, bufsize = 1024, path = '', log = False):
+    def __init__(self, ha=None, bufsize = 1024, path = '', log = False, umask=None):
         """Initialization method for instance.
 
            ha = host address duple (host, port)
@@ -617,6 +617,7 @@ class SocketUxdNb(object):
         self.txLog = None #transmit log
         self.rxLog = None #receive log
         self.log = log
+        self.umask = umask
 
     def openLogs(self, path = ''):
         """Open log files
@@ -665,15 +666,33 @@ class SocketUxdNb(object):
 
         self.ss.setblocking(0) #non blocking socket
 
+
+        oldumask = None
+        if self.umask is not None: # change umask for the uxd file
+            oldumask = os.umask(self.umask) # set new and return old
+
         #bind to Host Address Port
         try:
             self.ss.bind(self.ha)
-        except socket.error, e:
-            console.terse("socket.error = {0}\n".format(e))
-            return False
+        except socket.error as ex:
+            if not ex.errno == errno.ENOENT: # No such file or directory
+                console.terse("socket.error = {0}\n".format(ex))
+                return False
+            try:
+                os.makedirs(os.path.dirname(self.ha))
+            except OSError as ex:
+                console.terse("OSError = {0}\n".format(ex))
+                return False
+            try:
+                self.ss.bind(self.ha)
+            except socket.error as ex:
+                console.terse("socket.error = {0}\n".format(ex))
+                return False
+
+        if oldumask is not None: # restore old umask
+            os.umask(oldumask)
 
         self.ha = self.ss.getsockname() #get resolved ha after bind
-        #self.host, self.port = self.ha
 
         if self.log:
             if not self.openLogs():
@@ -721,8 +740,8 @@ class SocketUxdNb(object):
                 self.rxLog.write("%s\n%s\n" % (str(sa), repr(data)))
 
             return (data,sa)
-        except socket.error, ex1: # 2.6 socket.error is subclass of IOError
-            if ex1.errno == errno.EAGAIN: #Resource temporarily unavailable on os x
+        except socket.error as ex: # 2.6 socket.error is subclass of IOError
+            if ex.errno == errno.EAGAIN: #Resource temporarily unavailable on os x
                 return ('',None) #receive has nothing empty string for data
             else:
                 raise #re raise exception ex1
@@ -736,8 +755,8 @@ class SocketUxdNb(object):
         """
         try:
             result = self.ss.sendto(data,da) #result is number of bytes sent
-        except socket.error, e:
-            print "socket.error = %s" % e
+        except socket.error as ex:
+            print "socket.error = %s" % ex
             result = 0
 
         console.profuse("Server at {0} sent {1} bytes\n".format(str(self.ha),result))
